@@ -8,7 +8,7 @@ from requests import post
 # Set up arguments
 parser = ArgumentParser(description='A very simple OpenContest command line client written in Python')
 parser.add_argument('command', choices=['save', 'about', 'info', 'solves', 'history',
-                    'register', 'submit', 'status', 'submissions', 'code'])
+                    'user', 'submit', 'status', 'submissions', 'code'])
 parser.add_argument('-C', '--config', help='Config file path')
 parser.add_argument('-U', '--username', help='Your username')
 parser.add_argument('-H', '--homeserver', help='URL of your registration server')
@@ -56,7 +56,7 @@ requests = {
     'info': probleminfo,
     'solves': probleminfo,
     'history': probleminfo,
-    'register': ['name', 'email', 'username', 'password'],
+    'user': ['name', 'email', 'username', 'password'],
     'submit': userinfo + probleminfo + ['language', 'code'],
     'status': userinfo + probleminfo,
     'submissions': userinfo + probleminfo,
@@ -72,7 +72,7 @@ for field in requests[args.command]:
     elif field == 'token':
         # Prepare list of servers to authorize
         authorized_servers = args.server
-        if args.problem is not None and '' in args.problem:
+        if args.problem is not None and ' ' in args.problem:
             authorized_servers += ' ' + args.problem.split()[2]
         # Get token
         body['token'] = post(('https://' if args.homeserver.find('://') == -1 else '') + args.homeserver, json={
